// Web Components: Extending Native Elements, A working example

import CustomVideoElement from 'custom-video-element';
import shaka from 'shaka-player';

class ShakaVideoElement extends CustomVideoElement {
  constructor() {
    super();

    console.log(shaka);
  }

  get src() {
    // Use the attribute value as the source of truth.
    // No need to store it in two places.
    // This avoids needing a to read the attribute initially and update the src.
    return this.getAttribute('src');
  }

  set src(val) {
    // If being set by attributeChangedCallback,
    // dont' cause an infinite loop
    if (val !== this.src) {
      this.setAttribute('src', val);
    }
  }

  async load() {
    const player = new shaka.Player(this.nativeEl);

    // Listen for error events.
    player.addEventListener('error', onErrorEvent);

    // Try to load a manifest.
    // This is an asynchronous process.
    try {
      await player.load(this.src);
      // This runs if the asynchronous load is successful.
      console.log('The video has now been loaded!');
    } catch (e) {
      // onError is executed if the asynchronous load fails.
      onError(e);
    }

    function onErrorEvent(event) {
      // Extract the shaka.util.Error object from the event.
      onError(event.detail);
    }
    
    function onError(error) {
      // Log the error.
      console.error('Error code', error.code, 'object', error);
    }


    // if (Hls.isSupported()) {
    //   var hls = new Hls({
    //     // Kind of like preload metadata, but causes spinner.
    //     // autoStartLoad: false,
    //   });

    //   hls.loadSource(this.src);
    //   hls.attachMedia(this.nativeEl);
    // } else if (video.canPlayType('application/vnd.apple.mpegurl')) {
    //   this.nativeEl.src = this.src;
    // }
  }

  // play() {
  //   if (this.readyState === 0 && this.networkState < 2) {
  //     this.load();
  //     this.hls.on(Hls.Events.MANIFEST_PARSED,function() {
  //     video.play();
  //
  //     return this.nativeEl.play();
  //   }
  // }

  connectedCallback() {
    this.load();

    // Not preloading might require faking the play() promise
    // so that you can call play(), call load() within that
    // But wait until MANIFEST_PARSED to actually call play()
    // on the nativeEl.
    // if (this.preload === 'auto') {
    //   this.load();
    // }
  }
}

if (!window.customElements.get('shaka-video')) {
  window.customElements.define('shaka-video', ShakaVideoElement);
  window.ShakaVideoElement = ShakaVideoElement;
}

export default ShakaVideoElement;
